@@ -1,10 +1,11 @@
+import re
 import requests
 import json
 from deezer.gw import GW
 from deezer.api import API
 from deezer.errors import DeezerError, WrongLicense, WrongGeolocation
 
-__version__ = "1.2.5"
+__version__ = "1.2.7"
 
 class TrackFormats():
     """Number associtation for formats"""
@@ -54,6 +55,9 @@ class Deezer:
         if child: child = int(child)
         # Check if user already logged in
         user_data = self.gw.get_user_data()
+        if not user_data or user_data and len(user_data.keys()) == 0:
+            self.logged_in = False
+            return False
         if user_data['USER']['USER_ID'] == 0:
             self.logged_in = False
             return False
@@ -93,6 +97,9 @@ class Deezer:
         self.session.cookies.set_cookie(cookie_obj)
         user_data = self.gw.get_user_data()
         # Check if user logged in
+        if not user_data or user_data and len(user_data.keys()) == 0:
+            self.logged_in = False
+            return False
         if user_data["USER"]["USER_ID"] == 0:
             self.logged_in = False
             return False
@@ -134,7 +141,7 @@ class Deezer:
         if len(self.childs)-1 < child_n: child_n = 0
         self.current_user = self.childs[child_n]
         self.selected_account = child_n
-        self.http_headers["Accept-Language"] = self.current_user['language']
+        self.http_headers["Accept-Language"] = re.sub(r"[^0-9A-Za-z *,-.;=]", "", self.current_user['language'])
 
         return (self.current_user, self.selected_account)
 
